@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 our %SPEC;
 
@@ -34,7 +34,7 @@ sub head {
         push @$out, $item;
     }
 
-    [200, "OK", $out];
+    [200, "OK"];
 }
 
 1;
@@ -49,7 +49,7 @@ Data::Unixish::head - Output the first items of data
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 AUTHOR
 
